@@ -1,21 +1,55 @@
 /* eslint-disable no-undef */
-
 import * as _ from 'lodash-es';
-import * as React from 'react';
-import * as PropTypes from 'prop-types';
 import * as classNames from 'classnames';
 import * as fuzzy from 'fuzzysearch';
+import * as PropTypes from 'prop-types';
+import * as React from 'react';
 import { connect } from 'react-redux';
 import { Link } from 'react-router-dom';
-import { AutoSizer, List as VirtualList, WindowScroller, CellMeasurerCache, CellMeasurer } from 'react-virtualized';
+import {
+  AutoSizer,
+  CellMeasurer,
+  CellMeasurerCache,
+  List as VirtualList,
+  WindowScroller,
+} from 'react-virtualized';
 
-import { getJobTypeAndCompletions, isNodeReady, podPhase, podPhaseFilterReducer, podReadiness, K8sResourceKind, K8sKind, K8sResourceKindReference } from '../../module/k8s';
 import { UIActions } from '../../ui/ui-actions';
 import { ingressValidHosts } from '../ingress';
 import { routeStatus } from '../routes';
 import { secretTypeFilterReducer } from '../secret';
 import { bindingType, roleType } from '../RBAC';
-import { LabelList, ResourceCog, ResourceLink, resourcePath, Selector, StatusBox, containerLinuxUpdateOperator, EmptyBox } from '../utils';
+import {
+  alertState,
+  alertStateOrder,
+  silenceState,
+  silenceStateOrder,
+} from '../../monitoring';
+import {
+  containerLinuxUpdateOperator,
+  EmptyBox,
+  LabelList,
+  ResourceKebab,
+  ResourceLink,
+  resourcePath,
+  Selector,
+  StatusBox,
+} from '../utils';
+import {
+  getJobTypeAndCompletions,
+  nodeStatus,
+  K8sKind,
+  K8sResourceKind,
+  K8sResourceKindReference,
+  planExternalName,
+  podPhase,
+  podPhaseFilterReducer,
+  podReadiness,
+  serviceCatalogStatus,
+  serviceClassDisplayName,
+  getClusterOperatorStatus,
+  getClusterOperatorVersion,
+} from '../../module/k8s';
 
 const fuzzyCaseInsensitive = (a, b) => fuzzy(_.toLower(a), _.toLower(b));
 
@@ -23,6 +57,14 @@ const fuzzyCaseInsensitive = (a, b) => fuzzy(_.toLower(a), _.toLower(b));
 const listFilters = {
   'name': (filter, obj) => fuzzyCaseInsensitive(filter, obj.metadata.name),
 
+  'alert-name': (filter, alert) => fuzzyCaseInsensitive(filter, _.get(alert, 'labels.alertname')),
+
+  'alert-state': (filter, alert) => filter.selected.has(alertState(alert)),
+
+  'silence-name': (filter, silence) => fuzzyCaseInsensitive(filter, silence.name),
+
+  'silence-state': (filter, silence) => filter.selected.has(silenceState(silence)),
+
   // Filter role by role kind
   'role-kind': (filter, role) => filter.selected.has(roleType(role)),
 
@@ -54,9 +96,13 @@ const listFilters = {
     return phases.selected.has(phase) || !_.includes(phases.all, phase);
   },
 
-  'node-status': (status, node) => {
-    const isReady = isNodeReady(node);
-    return status === 'all' || (status === 'ready' && isReady) || (status === 'notReady' && !isReady);
+  'node-status': (statuses, node) => {
+    if (!statuses || !statuses.selected || !statuses.selected.size) {
+      return true;
+    }
+
+    const status = nodeStatus(node);
+    return statuses.selected.has(status) || !_.includes(statuses.all, status);
   },
 
   'clusterserviceversion-resource-kind': (filters, resource) => {
@@ -65,6 +111,16 @@ const listFilters = {
     }
     return filters.selected.has(resource.kind);
   },
+  'clusterserviceversion-status': (filters, csv) => {
+    if (!filters || !filters.selected || !filters.selected.size) {
+      return true;
+    }
+    return filters.selected.has(_.get(csv.status, 'reason')) || !_.includes(filters.all, _.get(csv.status, 'reason'));
+  },
+
+  'packagemanifest-name': (filter, pkg) => fuzzyCaseInsensitive(filter, (pkg.status.defaultChannel
+    ? pkg.status.channels.find(ch => ch.name === pkg.status.defaultChannel)
+    : pkg.status.channels[0]).currentCSVDesc.displayName),
 
   'build-status': (phases, build) => {
     if (!phases || !phases.selected || !phases.selected.size) {
@@ -89,7 +145,16 @@ const listFilters = {
       return true;
     }
 
-    let status = routeStatus(route);
+    const status = routeStatus(route);
+    return statuses.selected.has(status) || !_.includes(statuses.all, status);
+  },
+
+  'catalog-status': (statuses, catalog) => {
+    if (!statuses || !statuses.selected || !statuses.selected.size) {
+      return true;
+    }
+
+    const status = serviceCatalogStatus(catalog);
     return statuses.selected.has(status) || !_.includes(statuses.all, status);
   },
 
@@ -109,6 +174,21 @@ const listFilters = {
     const phase = pvc.status.phase;
     return phases.selected.has(phase) || !_.includes(phases.all, phase);
   },
+
+  // Filter service classes by text match
+  'service-class': (str, serviceClass) => {
+    const displayName = serviceClassDisplayName(serviceClass);
+    return fuzzyCaseInsensitive(str, displayName);
+  },
+
+  'cluster-operator-status': (statuses, operator) => {
+    if (!statuses || !statuses.selected || !statuses.selected.size) {
+      return true;
+    }
+
+    const status = getClusterOperatorStatus(operator);
+    return statuses.selected.has(status) || !_.includes(statuses.all, status);
+  },
 };
 
 const getFilteredRows = (_filters, objects) => {
@@ -131,7 +211,7 @@ const filterPropType = (props, propName, componentName) => {
     return;
   }
 
-  for (let key of _.keys(props[propName])) {
+  for (const key of _.keys(props[propName])) {
     if (key in listFilters || key === 'loadTest') {
       continue;
     }
@@ -140,9 +220,11 @@ const filterPropType = (props, propName, componentName) => {
 };
 
 const sorts = {
+  alertStateOrder,
   daemonsetNumScheduled: daemonset => _.toInteger(_.get(daemonset, 'status.currentNumberScheduled')),
   dataSize: resource => _.size(_.get(resource, 'data')),
   ingressValidHosts,
+  serviceCatalogStatus,
   jobCompletions: job => getJobTypeAndCompletions(job).completions,
   jobType: job => getJobTypeAndCompletions(job).type,
   nodeReadiness: node => {
@@ -152,9 +234,14 @@ const sorts = {
   },
   nodeUpdateStatus: node => _.get(containerLinuxUpdateOperator.getUpdateStatus(node), 'text'),
   numReplicas: resource => _.toInteger(_.get(resource, 'status.replicas')),
+  planExternalName,
   podPhase,
   podReadiness,
+  serviceClassDisplayName,
+  silenceStateOrder,
   string: val => JSON.stringify(val),
+  getClusterOperatorStatus,
+  getClusterOperatorVersion,
 };
 
 export class ColHead extends React.Component<ColHeadProps> {
@@ -178,10 +265,18 @@ export class ColHead extends React.Component<ColHeadProps> {
     }
   }
 
-  render () {
+  render() {
     // currentSortField/Func == info for currently sorted ColHead.
     // sortField/Func == this ColHead's field/func
-    const {applySort, children, currentSortField, currentSortFunc, currentSortOrder, sortField, sortFunc} = this.props;
+    const {
+      applySort,
+      children,
+      currentSortField,
+      currentSortFunc,
+      currentSortOrder,
+      sortField,
+      sortFunc,
+    } = this.props;
     const className = classNames(this.props.className, 'text-nowrap');
     if (!sortField && !sortFunc) {
       return <div className={className}>{children}</div>;
@@ -208,8 +303,13 @@ export const WorkloadListHeader = props => <ListHeader>
   <ColHead {...props} className="col-lg-3 hidden-md hidden-sm hidden-xs" sortField="spec.selector">Pod Selector</ColHead>
 </ListHeader>;
 
-export const Rows: React.SFC<RowsProps> = (props) => {
-  const { fake, label } = props;
+const getRowKey = (obj, index) => {
+  return _.get(obj, 'rowKey') || _.get(obj, 'metadata.uid', index);
+};
+
+const VirtualRows: React.SFC<RowsProps> = (props) => {
+  const { mock, label } = props;
+
   const measurementCache = new CellMeasurerCache({
     fixedWidth: true,
     minHeight: 44,
@@ -224,35 +324,36 @@ export const Rows: React.SFC<RowsProps> = (props) => {
       cache={measurementCache}
       columnIndex={0}
       key={key}
-      rowIndex={index}
-      parent={parent}>
-      <div style={style}>
-        <Row key={_.get(obj, 'metadata.uid', index)} obj={obj} expand={expand} kindObj={kindObj} index={index} />
+      parent={parent}
+      rowIndex={index}>
+      <div style={style} className="co-m-row">
+        <Row key={getRowKey(obj, index)} obj={obj} expand={expand} kindObj={kindObj} index={index} />
       </div>
     </CellMeasurer>;
   };
 
+  // Default `height` to 0 to avoid console errors from https://github.com/bvaughn/react-virtualized/issues/1158
   return <div className="co-m-table-grid__body">
-    { fake
+    { mock
       ? <EmptyBox label={label} />
-      : <WindowScroller>
+      : <WindowScroller scrollElement={document.getElementById('content-scrollable')}>
         {({height, isScrolling, registerChild, onChildScroll, scrollTop}) =>
           <AutoSizer disableHeight>
             {({width}) => <div ref={registerChild}>
               <VirtualList
                 autoHeight
                 data={props.data}
-                expand={props.expand}
-                height={height}
                 deferredMeasurementCache={measurementCache}
-                rowHeight={measurementCache.rowHeight}
+                expand={props.expand}
+                height={height || 0}
                 isScrolling={isScrolling}
                 onScroll={onChildScroll}
-                rowRenderer={rowRenderer}
                 rowCount={props.data.length}
+                rowHeight={measurementCache.rowHeight}
+                rowRenderer={rowRenderer}
                 scrollTop={scrollTop}
-                width={width}
                 tabIndex={null}
+                width={width}
               />
             </div>}
           </AutoSizer>}
@@ -261,19 +362,42 @@ export const Rows: React.SFC<RowsProps> = (props) => {
   </div>;
 };
 
+VirtualRows.propTypes = {
+  data: PropTypes.arrayOf(PropTypes.object),
+  expand: PropTypes.bool,
+  Row: PropTypes.func.isRequired,
+  kindObj: PropTypes.any,
+  label: PropTypes.string,
+  mock: PropTypes.bool,
+};
+
+const Rows: React.SFC<RowsProps> = (props) => {
+  const {Row, expand, kindObj} = props;
+
+  return <div className="co-m-table-grid__body">
+    { props.data.map((obj, i) => <div key={getRowKey(obj, i)} className="co-m-row">
+      <Row obj={obj} expand={expand} kindObj={kindObj} />
+    </div>) }
+  </div>;
+};
+
 Rows.propTypes = {
   data: PropTypes.arrayOf(PropTypes.object),
   expand: PropTypes.bool,
   Row: PropTypes.func.isRequired,
+  kindObj: PropTypes.any,
+  label: PropTypes.string,
+  mock: PropTypes.bool,
 };
 
-const stateToProps = ({UI}, {data = [], filters = {}, loaded = false, reduxID = null, reduxIDs = null, staticFilters = [{}]}) => {
+const stateToProps = ({UI}, {data = [], defaultSortField = 'metadata.name', defaultSortFunc = undefined, filters = {}, loaded = false, reduxID = null, reduxIDs = null, staticFilters = [{}]}) => {
   const allFilters = staticFilters ? Object.assign({}, filters, ...staticFilters) : filters;
   let newData = getFilteredRows(allFilters, data);
 
   const listId = reduxIDs ? reduxIDs.join(',') : reduxID;
-  const currentSortField = UI.getIn(['listSorts', listId, 'field'], 'metadata.name');
-  const currentSortFunc = UI.getIn(['listSorts', listId, 'func']);
+  // Only default to 'metadata.name' if no `defaultSortFunc`
+  const currentSortField = UI.getIn(['listSorts', listId, 'field'], defaultSortFunc ? undefined : defaultSortField);
+  const currentSortFunc = UI.getIn(['listSorts', listId, 'func'], defaultSortFunc);
   const currentSortOrder = UI.getIn(['listSorts', listId, 'orderBy'], 'asc');
 
   if (loaded) {
@@ -290,7 +414,13 @@ const stateToProps = ({UI}, {data = [], filters = {}, loaded = false, reduxID =
     newData = _.orderBy(newData, [sortBy, 'metadata.name'], [currentSortOrder, 'asc']);
   }
 
-  return {currentSortField, currentSortFunc, currentSortOrder, data: newData, listId};
+  return {
+    currentSortField,
+    currentSortFunc,
+    currentSortOrder,
+    data: newData,
+    listId,
+  };
 };
 
 export const List = connect(stateToProps, {sortList: UIActions.sortList})(
@@ -304,33 +434,49 @@ export const List = connect(stateToProps, {sortList: UIActions.sortList})(
       Header: PropTypes.func.isRequired,
       loaded: PropTypes.bool,
       loadError: PropTypes.oneOfType([PropTypes.object, PropTypes.string]),
+      mock: PropTypes.bool,
       namespace: PropTypes.string,
       reduxID: PropTypes.string,
       reduxIDs: PropTypes.array,
       Row: PropTypes.func.isRequired,
       selector: PropTypes.object,
       staticFilters: PropTypes.array,
-      fake: PropTypes.bool,
+      virtualize: PropTypes.bool,
+      currentSortField: PropTypes.string,
+      currentSortFunc: PropTypes.string,
+      currentSortOrder: PropTypes.any,
+      defaultSortField: PropTypes.string,
+      defaultSortFunc: PropTypes.string,
+      label: PropTypes.string,
+      listId: PropTypes.string,
+      sortList: PropTypes.func,
     };
 
     render() {
-      const {currentSortField, currentSortFunc, currentSortOrder, expand, Header, label, listId, Row, sortList, fake} = this.props;
+      const {currentSortField, currentSortFunc, currentSortOrder, expand, Header, label, listId, mock, Row, sortList, virtualize = true} = this.props;
       const componentProps: any = _.pick(this.props, ['data', 'filters', 'selected', 'match', 'kindObj']);
-
+      const ListRows = virtualize ? VirtualRows : Rows;
       const children = <React.Fragment>
         <Header
-          key="header"
+          {...componentProps}
           applySort={_.partial(sortList, listId)}
           currentSortField={currentSortField}
           currentSortFunc={currentSortFunc}
           currentSortOrder={currentSortOrder}
+          key="header"
+        />
+        <ListRows
           {...componentProps}
+          expand={expand}
+          key="rows"
+          label={label}
+          mock={mock}
+          Row={Row}
         />
-        <Rows key="rows" expand={expand} Row={Row} fake={fake} label={label} {...componentProps} />
       </React.Fragment>;
 
       return <div className="co-m-table-grid co-m-table-grid--bordered">
-        { fake ? children : <StatusBox {...this.props}>{children}</StatusBox> }
+        { mock ? children : <StatusBox {...this.props}>{children}</StatusBox> }
       </div>;
     }
   });
@@ -340,7 +486,7 @@ export class ResourceRow extends React.Component<ResourceRowProps> {
     if (_.size(nextProps) !== _.size(this.props)) {
       return true;
     }
-    for (let key of Object.keys(nextProps)) {
+    for (const key of Object.keys(nextProps)) {
       if (key === 'obj') {
         const oldVersion = _.get(this.props.obj, 'metadata.resourceVersion');
         const newVersion = _.get(nextProps.obj, 'metadata.resourceVersion');
@@ -356,14 +502,13 @@ export class ResourceRow extends React.Component<ResourceRowProps> {
     return false;
   }
 
-  render () {
+  render() {
     return <div className="row co-resource-list__item" style={this.props.style}>{this.props.children}</div>;
   }
 }
 
 export const WorkloadListRow: React.SFC<WorkloadListRowProps> = ({kind, actions, obj: o}) => <ResourceRow obj={o}>
-  <div className="col-lg-2 col-md-3 col-sm-4 col-xs-6 co-resource-link-wrapper">
-    <ResourceCog actions={actions} kind={kind} resource={o} />
+  <div className="col-lg-2 col-md-3 col-sm-4 col-xs-6">
     <ResourceLink kind={kind} name={o.metadata.name} namespace={o.metadata.namespace} title={o.metadata.uid} />
   </div>
   <div className="col-lg-2 col-md-3 col-sm-4 col-xs-6 co-break-word">
@@ -380,6 +525,9 @@ export const WorkloadListRow: React.SFC<WorkloadListRowProps> = ({kind, actions,
   <div className="col-lg-3 hidden-md hidden-sm hidden-xs">
     <Selector selector={o.spec.selector} namespace={o.metadata.namespace} />
   </div>
+  <div className="dropdown-kebab-pf">
+    <ResourceKebab actions={actions} kind={kind} resource={o} />
+  </div>
 </ResourceRow>;
 
 export type ColHeadProps = {
@@ -394,27 +542,30 @@ export type ColHeadProps = {
 };
 
 export type ListInnerProps = {
-  Header: React.ComponentType<any>;
-  Row: React.ComponentType<any>;
+  currentSortField?: string;
+  currentSortFunc?: string;
+  currentSortOrder?: any;
   data?: any[];
-  label?: string;
+  defaultSortField?: string;
+  defaultSortFunc?: string;
   EmptyMsg?: React.ComponentType<{}>;
   expand?: boolean;
   fieldSelector?: string;
   filters?: {[name: string]: any};
+  Header: React.ComponentType<any>;
+  label?: string;
+  listId?: string;
   loaded?: boolean;
   loadError?: string | Object;
+  mock?: boolean;
   namespace?: string;
   reduxID?: string;
   reduxIDs?: string[];
+  Row: React.ComponentType<any>;
   selector?: Object;
-  staticFilters?: any[];
-  fake?: boolean;
-  currentSortField?: string;
-  currentSortFunc?: Function;
-  currentSortOrder?: any;
-  listId?: string;
   sortList?: (...args) => any;
+  staticFilters?: any[];
+  virtualize?: boolean;
 };
 
 export type ResourceRowProps = {
@@ -425,17 +576,18 @@ export type ResourceRowProps = {
 export type RowsProps = {
   data?: any[];
   expand?: boolean;
-  fake?: boolean;
-  label?: string;
-  Row: React.ComponentType<any>;
   kindObj?: K8sKind;
+  label?: string;
+  mock?: boolean;
+  Row: React.ComponentType<any>;
 };
 
 export type WorkloadListRowProps = {
-  kind: K8sResourceKindReference;
   actions: any;
+  kind: K8sResourceKindReference;
   obj: K8sResourceKind;
 };
 
 Rows.displayName = 'Rows';
+VirtualRows.displayName = 'VirtualRows';
 WorkloadListRow.displayName = 'WorkloadListRow';
