@@ -1,7 +1,6 @@
 import * as _ from 'lodash-es';
 import * as React from 'react';
 import { Link } from 'react-router-dom';
-import * as classNames from 'classnames';
 
 import { selectorToString } from '../../module/k8s/selector';
 
@@ -19,19 +18,16 @@ const Requirement = ({kind, requirements, namespace=''}) => {
 
   return (
     <div className="co-m-requirement">
-      <Link className={`co-text-${kind.toLowerCase()}`} to={to} tabIndex={-1}>
-        <i className="fa fa-search"></i> {requirementAsString.replace(/,/g, ', ')}
+      <Link className={`co-m-requirement__link co-text-${kind.toLowerCase()}`} to={to} tabIndex={-1}>
+        <i className="co-m-requirement__icon fa fa-search" aria-hidden="true"></i>
+        <span className="co-m-requirement__label">{requirementAsString.replace(/,/g, ', ')}</span>
       </Link>
     </div>
   );
 };
 
-export const Selector = ({kind = 'Pod', expand = false, selector = {}, namespace = undefined, style = {}}) => {
-  const className = classNames('co-m-selector', {'co-m-selector--expand': expand});
-
-  return <div className={className} style={style}>
-    { _.isEmpty(selector)
-      ? <p className="text-muted">No selector</p>
-      : <Requirement kind={kind} requirements={selector} namespace={namespace} /> }
-  </div>;
-};
+export const Selector = ({kind = 'Pod', selector = {}, namespace = undefined}) => <div className="co-m-selector">
+  { _.isEmpty(selector)
+    ? <p className="text-muted">No selector</p>
+    : <Requirement kind={kind} requirements={selector} namespace={namespace} /> }
+</div>;
