@@ -72,15 +72,15 @@ spec:
     matchLabels:
       app: api
   ingress:
-  - from:
-    - podSelector:
-          matchLabels:
-            role: monitoring
-  - ports:
-    - protocol: TCP
-      port: 80
-    - protocol: TCP
-      port: 443
+    - from:
+        - podSelector:
+            matchLabels:
+              role: monitoring
+      ports:
+        - protocol: TCP
+          port: 80
+        - protocol: TCP
+          port: 443
 `).setIn([referenceForModel(k8sModels.NetworkPolicyModel), 'default-deny-all'], `
 apiVersion: networking.k8s.io/v1
 kind: NetworkPolicy
@@ -127,18 +127,14 @@ spec:
   ingress:
     - from:
       - namespaceSelector:
-        matchLabels:
-        env: production
+          matchLabels:
+            env: production
 `).setIn([referenceForModel(k8sModels.BuildConfigModel), 'default'], `
 apiVersion: build.openshift.io/v1
 kind: BuildConfig
 metadata:
   name: example
 spec:
-  output:
-    to:
-      kind: ImageStreamTag
-      name: example:latest
   source:
     git:
       ref: master
@@ -189,15 +185,6 @@ spec:
         image: openshift/hello-openshift
         ports:
         - containerPort: 8080
-`).setIn([referenceForModel(k8sModels.ClusterModel), 'default'], `
-apiVersion: multicluster.coreos.com/v1
-kind: Cluster
-metadata:
-  name: example
-  annotations:
-    'multicluster.coreos.com/console-url': 'http://localhost:9000'
-    'multicluster.coreos.com/directory': true
-spec: {}
 `).setIn([referenceForModel(k8sModels.ConfigMapModel), 'default'], `
 apiVersion: v1
 kind: ConfigMap
@@ -478,13 +465,7 @@ spec:
     - ReadWriteOnce
   resources:
     requests:
-      storage: 8Gi
-  storageClassName: slow
-  selector:
-    matchLabels:
-      release: "stable"
-    matchExpressions:
-      - {key: environment, operator: In, values: [dev]}
+      storage: 1Gi
 `).setIn([referenceForModel(k8sModels.ResourceQuotaModel), 'default'], `
 apiVersion: v1
 kind: ResourceQuota
@@ -497,6 +478,18 @@ spec:
     requests.memory: 1Gi
     limits.cpu: "2"
     limits.memory: 2Gi
+`).setIn([referenceForModel(k8sModels.LimitRangeModel), 'default'], `
+apiVersion: v1
+kind: LimitRange
+metadata:
+  name: mem-limit-range
+spec:
+  limits:
+  - default:
+      memory: 512Mi
+    defaultRequest:
+      memory: 256Mi
+    type: Container
 `).setIn([referenceForModel(k8sModels.StatefulSetModel), 'default'], `
 apiVersion: apps/v1
 kind: StatefulSet
@@ -693,4 +686,115 @@ spec:
     type: JenkinsPipeline
   triggers:
   - type: ConfigChange
+`).setIn([referenceForModel(k8sModels.ClusterServiceBrokerModel), 'default'], `
+apiVersion: servicecatalog.k8s.io/v1beta1
+kind: ClusterServiceBroker
+metadata:
+  name: example-cluster-service-broker
+spec:
+  url: https://example.com/broker/
+`).setIn([referenceForModel(k8sModels.ResourceQuotaModel), 'rq-compute'], `
+apiVersion: v1
+kind: ResourceQuota
+metadata:
+  name: compute-quota
+  namespace:
+spec:
+  hard:
+    requests.cpu: '1'
+    requests.memory: 1Gi
+    limits.cpu: '2'
+    limits.memory: 2Gi
+`).setIn([referenceForModel(k8sModels.ResourceQuotaModel), 'rq-storageclass'], `
+apiVersion: v1
+kind: ResourceQuota
+metadata:
+  name: storage-class-quota
+  namespace:
+spec:
+  hard:
+    requests.storage: 100Gi
+    persistentvolumeclaims: 100
+    # For quota specific to a storage class, the storage class must have the same name
+    gold.storage-class.kubernetes.io/requests.storage: 3Gi
+    gold.storage-class.kubernetes.io/persistentvolumeclaims: 5
+    silver.storage-class.kubernetes.io/requests.storage: 2Gi
+    silver.storage-class.kubernetes.io/persistentvolumeclaims: 3
+    bronze.storage-class.kubernetes.io/requests.storage: 1Gi
+    bronze.storage-class.kubernetes.io/persistentvolumeclaims: 1
+`).setIn([referenceForModel(k8sModels.ResourceQuotaModel), 'rq-counts'], `
+apiVersion: v1
+kind: ResourceQuota
+metadata:
+  name: object-counts
+  namespace:
+spec:
+  hard:
+    configmaps: "10"
+    persistentvolumeclaims: "4"
+    replicationcontrollers: "20"
+    secrets: "10"
+    services: "10"
+    services.loadbalancers: "2"
+`).setIn([referenceForModel(k8sModels.ClusterAutoscalerModel), 'default'], `
+apiVersion: "autoscaling.openshift.io/v1"
+kind: "ClusterAutoscaler"
+metadata:
+  name: "default"
+spec: {}
+`).setIn([referenceForModel(k8sModels.MachineDeploymentModel), 'default'], `
+apiVersion: "machine.openshift.io/v1beta1"
+kind: MachineDeployment
+metadata:
+  name: example
+spec:
+  replicas: 3
+  selector:
+    matchLabels:
+      foo: bar
+  template:
+    metadata:
+      labels:
+        foo: bar
+    spec:
+      providerSpec: {}
+      versions:
+        kubelet: ""
+`).setIn([referenceForModel(k8sModels.MachineSetModel), 'default'], `
+apiVersion: "machine.openshift.io/v1beta1"
+kind: MachineSet
+metadata:
+  name: example
+spec:
+  replicas: 3
+  selector:
+    matchLabels:
+      foo: bar
+  template:
+    metadata:
+      labels:
+        foo: bar
+    spec:
+      providerSpec: {}
+      versions:
+        kubelet: ""
+`).setIn([referenceForModel(k8sModels.MachineModel), 'default'], `
+apiVersion: "machine.openshift.io/v1beta1"
+kind: Machine
+metadata:
+  name: example
+spec:
+  providerSpec: {}
+`).setIn([referenceForModel(k8sModels.MachineConfigPoolModel), 'default'], `
+apiVersion: machineconfiguration.openshift.io/v1
+kind: MachineConfigPool
+metadata:
+  name: example
+spec:
+  machineConfigSelector:
+    matchLabels:
+      machineconfiguration.openshift.io/role: master
+  machineSelector:
+    matchLabels:
+      node-role.kubernetes.io/master: ""
 `);
